==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/si_LK.js <==
OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "ගොනු මාදිලිය දෝෂ සහිතයි",
    "Invalid image" : "පින්තුරය දෝෂ සහිතයි",
    "today" : "අද",
    "yesterday" : "ඊයේ",
    "last month" : "පෙර මාසයේ",
    "last year" : "පෙර අවුරුද්දේ",
    "seconds ago" : "තත්පරයන්ට පෙර",
    "__language_name__" : "සිංහල",
    "Help" : "උදව්",
    "Apps" : "යෙදුම්",
    "Settings" : "සැකසුම්",
    "Log out" : "නික්මීම",
    "Users" : "පරිශීලකයන්",
    "Unknown user" : "හදුනානොගත් සේවාදායකයා",
    "Sharing" : "හුවමාරු කිරීම",
    "Sunday" : "ඉරිදා",
    "Monday" : "සඳුදා",
    "Tuesday" : "අඟහරුවාදා",
    "Wednesday" : "බදාදා",
    "Thursday" : "බ්‍රහස්පතින්දා",
    "Friday" : "සිකුරාදා",
    "Saturday" : "සෙනසුරාදා",
    "Sun." : "ඉරිදා",
    "Mon." : "සඳුදා",
    "Tue." : "අඟ.",
    "Wed." : "බදාදා",
    "Thu." : "බ්‍රහස්.",
    "Fri." : "සිකු.",
    "Sat." : "සෙන.",
    "January" : "ජනවාරි",
    "February" : "පෙබරවාරි",
    "March" : "මාර්තු",
    "April" : "අප්‍රේල්",
    "May" : "මැයි",
    "June" : "ජූනි",
    "July" : "ජූලි",
    "August" : "අගෝස්තු",
    "September" : "සැප්තැම්බර්",
    "October" : "ඔක්තෝබර",
    "November" : "නොවැම්බර්",
    "December" : "දෙසැම්බර්",
    "Jan." : "ජන.",
    "Feb." : "පෙබ.",
    "Mar." : "මාර්තු",
    "Apr." : "අප්‍රේල්",
    "May." : "මැයි",
    "Jun." : "ජුනි",
    "Jul." : "ජුලි",
    "Aug." : "අගෝ.",
    "Sep." : "සැප්.",
    "Oct." : "ඔක්.",
    "Nov." : "නොවැ.",
    "Dec." : "දෙසැ.",
    "Application is not enabled" : "යෙදුම සක්‍රිය කර නොමැත",
    "Authentication error" : "සත්‍යාපන දෝෂයක්",
    "Token expired. Please reload page." : "ටෝකනය කල් ඉකුත් වී ඇත. පිටුව නැවුම් කරන්න",
    "Create" : "තනන්න",
    "Delete" : "ඉවත් කරන්න",
    "Share" : "බෙදා හදා ගන්න"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/si_LK.js <==
OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "ගොනු මාදිලිය දෝෂ සහිතයි",
    "Invalid image" : "පින්තුරය දෝෂ සහිතයි",
    "today" : "අද",
    "yesterday" : "ඊයේ",
    "last month" : "පෙර මාසයේ",
    "last year" : "පෙර අවුරුද්දේ",
    "seconds ago" : "තත්පරයන්ට පෙර",
    "__language_name__" : "සිංහල",
    "Help" : "උදව්",
    "Apps" : "යෙදුම්",
    "Settings" : "සැකසුම්",
    "Log out" : "නික්මීම",
    "Users" : "පරිශීලකයන්",
    "Unknown user" : "හදුනානොගත් සේවාදායකයා",
    "Sunday" : "ඉරිදා",
    "Monday" : "සඳුදා",
    "Tuesday" : "අඟහරුවාදා",
    "Wednesday" : "බදාදා",
    "Thursday" : "බ්‍රහස්පතින්දා",
    "Friday" : "සිකුරාදා",
    "Saturday" : "සෙනසුරාදා",
    "Sun." : "ඉරිදා",
    "Mon." : "සඳුදා",
    "Tue." : "අඟ.",
    "Wed." : "බදාදා",
    "Thu." : "බ්‍රහස්.",
    "Fri." : "සිකු.",
    "Sat." : "සෙන.",
    "January" : "ජනවාරි",
    "February" : "පෙබරවාරි",
    "March" : "මාර්තු",
    "April" : "අප්‍රේල්",
    "May" : "මැයි",
    "June" : "ජූනි",
    "July" : "ජූලි",
    "August" : "අගෝස්තු",
    "September" : "සැප්තැම්බර්",
    "October" : "ඔක්තෝබර",
    "November" : "නොවැම්බර්",
    "December" : "දෙසැම්බර්",
    "Jan." : "ජන.",
    "Feb." : "පෙබ.",
    "Mar." : "මාර්තු",
    "Apr." : "අප්‍රේල්",
    "May." : "මැයි",
    "Jun." : "ජුනි",
    "Jul." : "ජුලි",
    "Aug." : "අගෝ.",
    "Sep." : "සැප්.",
    "Oct." : "ඔක්.",
    "Nov." : "නොවැ.",
    "Dec." : "දෙසැ.",
    "Application is not enabled" : "යෙදුම සක්‍රිය කර නොමැත",
    "Authentication error" : "සත්‍යාපන දෝෂයක්",
    "Token expired. Please reload page." : "ටෝකනය කල් ඉකුත් වී ඇත. පිටුව නැවුම් කරන්න",
    "Create" : "තනන්න",
    "Delete" : "ඉවත් කරන්න",
    "Share" : "බෙදා හදා ගන්න",
    "Sharing" : "හුවමාරු කිරීම"
},
"nplurals=2; plural=(n != 1);");
